SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[netPageDataLoad]') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[netPageDataLoad]
GO

CREATE PROCEDURE dbo.netPageDataLoad
(
	@PageID	INT, 
	@LanguageBranchID INT
)
AS
BEGIN
	SET NOCOUNT ON

	DECLARE @PageTypeID INT

	SELECT @PageTypeID = tblPage.fkPageTypeID FROM tblPage
		WHERE tblPage.pkID=@PageID

	/*This procedure should always return a page (if exist), preferable in requested language else in master language*/
	IF (@LanguageBranchID = -1 OR NOT EXISTS (SELECT Name FROM tblPageLanguage WHERE fkPageID=@PageID AND fkLanguageBranchID = @LanguageBranchID))
		SELECT @LanguageBranchID = fkMasterLanguageBranchID  FROM tblPage
			WHERE tblPage.pkID=@PageID

	/* Get data for page */
	SELECT
		tblPage.pkID AS PageLinkID,
		NULL AS PageLinkWorkID,
		fkParentID  AS PageParentLinkID,
		fkPageTypeID AS PageTypeID,
		NULL AS PageTypeName,
		CONVERT(INT,VisibleInMenu) AS PageVisibleInMenu,
		ChildOrderRule AS PageChildOrderRule,
		PeerOrder AS PagePeerOrder,
		CONVERT(NVARCHAR(38),tblPage.PageGUID) AS PageGUID,
		fkArchivePageID AS PageArchiveLinkID,
		ExternalFolderID AS PageFolderID,
		CONVERT(INT,Deleted) AS PageDeleted,
		(SELECT ChildOrderRule FROM tblPage AS ParentPage WHERE ParentPage.pkID=tblPage.fkParentID) AS PagePeerOrderRule,
		fkMasterLanguageBranchID AS PageMasterLanguageBranchID,
		CreatorName
	FROM tblPage
	WHERE tblPage.pkID=@PageID

	IF (@@ROWCOUNT = 0)
		RETURN 0
		
	/* Get data for page languages */
	SELECT
		L.fkPageID AS PageID,
		CASE L.AutomaticLink
			WHEN 1 THEN
				(CASE
					WHEN L.fkPageLinkID IS NULL THEN 0	/* EPnLinkNormal */
					WHEN L.FetchData=1 THEN 4				/* EPnLinkFetchdata */
					ELSE 1								/* EPnLinkShortcut */
				END)
			ELSE
				(CASE
					WHEN L.LinkURL=N'#' THEN 3				/* EPnLinkInactive */
					ELSE 2								/* EPnLinkExternal */
				END)
		END AS PageShortcutType,
		L.ExternalURL AS PageExternalURL,
		L.fkPageLinkID AS PageShortcutLinkID,
		L.Name AS PageName,
		L.URLSegment AS PageURLSegment,
		L.LinkURL AS PageLinkURL,
		L.Created AS PageCreated,
		L.Changed AS PageChanged,
		L.Saved AS PageSaved,
		L.StartPublish AS PageStartPublish,
		L.StopPublish AS PageStopPublish,
		CONVERT(INT,L.PendingPublish) AS PagePendingPublish,
		L.CreatorName AS PageCreatedBy,
		L.ChangedByName AS PageChangedBy,
		-- RTRIM(tblPageLanguage.fkLanguageID) AS PageLanguageID,
		L.fkFrameID AS PageTargetFrame,
		0 AS PageChangedOnPublish,
		0 AS PageDelayedPublish,
		L.fkLanguageBranchID AS PageLanguageBranchID,
		CASE 
			WHEN L.PendingPublish=1 THEN 2			/* EPnWorkStatusCheckedOut */
			ELSE 4									/* EPnWorkStatusPublished */
		END AS PageWorkStatus
	FROM tblPageLanguage AS L
	WHERE L.fkPageID=@PageID
		AND L.fkLanguageBranchID=@LanguageBranchID
	
	/* Get the property definitions*/
	SELECT
		@PageID AS PageID,
		tblPageDefinition.Name AS PropertyName,
		tblPageDefinition.LanguageSpecific,
		COALESCE(PDT.Property,tblPageDefinition.Property) AS PropertyType,
		CONVERT(INT, Required) AS Required,
		tblPageDefinition.pkID AS fkPageDefinitionID,
		tblPageDefinition.Advanced AS OwnerTab,
		TypeName,
		AssemblyName,
		LongStringSettings,
		FieldOrder,
		NULL AS Guid,
		DisplayEditUI
	FROM tblPageDefinition INNER JOIN tblPageType on tblPageDefinition.fkPageTypeID = tblPageType.pkID
		LEFT JOIN tblPageDefinitionType AS PDT ON PDT.pkID=tblPageDefinition.fkPageDefinitionTypeID
	WHERE tblPageDefinition.fkPageTypeID = @PageTypeID
	ORDER BY FieldOrder,tblPageDefinition.pkID

	/* Get the property data for the requested language */
	SELECT
		tblPageDefinition.Name AS PropertyName,
		CONVERT(INT, Boolean) AS Boolean,
		Number AS IntNumber,
		FloatNumber,
		PageType,
		PageLink AS PageLinkID,
		Date AS DateValue,
		String,
		LongString,
		LongStringSettings,
		tblProperty.fkLanguageBranchID AS LanguageBranchID
	FROM tblProperty
	INNER JOIN tblPageDefinition ON tblPageDefinition.pkID = tblProperty.fkPageDefinitionID
	WHERE tblProperty.fkPageID=@PageID AND NOT tblPageDefinition.fkPageTypeID IS NULL
		AND tblProperty.fkLanguageBranchID = @LanguageBranchID
	ORDER BY tblProperty.fkLanguageBranchID,FieldOrder,tblProperty.fkPageDefinitionID

	/*Get category information*/
	SELECT fkPageID AS PageID,fkCategoryID,CategoryType
	FROM tblCategoryPage
	WHERE fkPageID=@PageID AND CategoryType=0
	ORDER BY fkCategoryID

	/* Get access information */
	SELECT
		fkPageID AS PageID,
		Name,
		IsRole,
		AccessMask
	FROM
		tblAccess
	WHERE 
	    fkPageID=@PageID
	ORDER BY
	    IsRole DESC,
		Name

	/* Get all languages for the page */
	SELECT fkLanguageBranchID as PageLanguageBranchID FROM tblPageLanguage
		WHERE tblPageLanguage.fkPageID=@PageID
		
	RETURN 0
END
GO
