SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].netPageListPaged') AND OBJECTPROPERTY(id, N'IsProcedure') = 1)
DROP PROCEDURE [dbo].[netPageListPaged]
GO

CREATE PROCEDURE dbo.netPageListPaged
(
	@Binary VARBINARY(8000),
	@Threshold INT = 0
)
AS
BEGIN
	SET NOCOUNT ON

	DECLARE @Pages TABLE (LocalPageID INT)
	DECLARE	@Length SMALLINT
	DECLARE @Index SMALLINT
	SET @Index = 1
	SET @Length = DATALENGTH(@Binary)
	WHILE (@Index <= @Length)
	BEGIN
		INSERT INTO @Pages VALUES(SUBSTRING(@Binary, @Index, 4))
		SET @Index = @Index + 4
	END

	/* Get all pages included languages*/
	SELECT tblPageLanguage.fkPageID as PageID, tblPageLanguage.fkLanguageBranchID as PageLanguageBranchID FROM tblPageLanguage
		INNER JOIN @Pages on LocalPageID=tblPageLanguage.fkPageID
		ORDER BY tblPageLanguage.fkPageID

/* Get data for page */
	SELECT
		LocalPageID AS PageLinkID,
		NULL AS PageLinkWorkID,
		fkParentID  AS PageParentLinkID,
		fkPageTypeID AS PageTypeID,
		NULL AS PageTypeName,
		CONVERT(INT,VisibleInMenu) AS PageVisibleInMenu,
		ChildOrderRule AS PageChildOrderRule,
		0 AS PagePeerOrderRule,	-- No longer used
		PeerOrder AS PagePeerOrder,
		CONVERT(NVARCHAR(38),tblPage.PageGUID) AS PageGUID,
		fkArchivePageID AS PageArchiveLinkID,
		ExternalFolderID AS PageFolderID,
		CONVERT(INT,Deleted) AS PageDeleted,
		fkMasterLanguageBranchID AS PageMasterLanguageBranchID,
		CreatorName
	FROM @Pages
	INNER JOIN tblPage ON LocalPageID=tblPage.pkID
	ORDER BY tblPage.pkID

	IF (@@ROWCOUNT = 0)
	BEGIN
		RETURN
	END

	/* Get data for page languages */
	SELECT
		CASE 
			WHEN L.PendingPublish=1 THEN 2			/* EPnWorkStatusCheckedOut */
			ELSE 4									/* EPnWorkStatusPublished */
		END AS PageWorkStatus,
		L.fkPageID AS PageID,
		CASE AutomaticLink
			WHEN 1 THEN
				(CASE
					WHEN L.fkPageLinkID IS NULL THEN 0	/* EPnLinkNormal */
					WHEN L.FetchData=1 THEN 4				/* EPnLinkFetchdata */
					ELSE 1								/* EPnLinkShortcut */
				END)
			ELSE
				(CASE
					WHEN L.LinkURL=N'#' THEN 3				/* EPnLinkInactive */
					ELSE 2								/* EPnLinkExternal */
				END)
		END AS PageShortcutType,
		L.ExternalURL AS PageExternalURL,
		L.fkPageLinkID AS PageShortcutLinkID,
		L.Name AS PageName,
		L.URLSegment AS PageURLSegment,
		L.LinkURL AS PageLinkURL,
		L.Created AS PageCreated,
		L.Changed AS PageChanged,
		L.Saved AS PageSaved,
		L.StartPublish AS PageStartPublish,
		L.StopPublish AS PageStopPublish,
		CONVERT(INT,L.PendingPublish) AS PagePendingPublish,
		L.CreatorName AS PageCreatedBy,
		L.ChangedByName AS PageChangedBy,
		L.fkFrameID AS PageTargetFrame,
		0 AS PageChangedOnPublish,
		0 AS PageDelayedPublish,
		L.fkLanguageBranchID AS PageLanguageBranchID
	FROM @Pages AS P
	INNER JOIN tblPageLanguage AS L ON LocalPageID=L.fkPageID
	ORDER BY L.fkPageID, L.fkLanguageBranchID

	IF (@@ROWCOUNT = 0)
	BEGIN
		RETURN
	END
		
	
	/* Get the properties */
	/* NOTE! The CASE:s for LongString and Guid uses the precomputed LongStringLength to avoid 
	referencing LongString which may slow down the query */
	SELECT
		tblProperty.fkPageID AS PageID,
		tblPageDefinition.Name AS PropertyName,
		tblPageDefinition.LanguageSpecific,
		COALESCE(PDT.Property,tblPageDefinition.Property) AS PropertyType,
		CONVERT(INT, Required) AS Required,
		CONVERT(INT, Boolean) AS Boolean,
		Number AS IntNumber,
		FloatNumber,
		PageType,
		PageLink AS PageLinkID,
		Date AS DateValue,
		String,
		(CASE 
			WHEN (@Threshold = 0) OR (COALESCE(LongStringLength, 2147483647) < @Threshold) THEN
				LongString
			ELSE
				NULL
		END) AS LongString,
		fkPageDefinitionID,
		tblPageDefinition.Advanced AS OwnerTab,
		TypeName,
		AssemblyName,
		LongStringSettings,
		tblProperty.fkLanguageBranchID AS LanguageBranchID,
		FieldOrder,
		(CASE 
			WHEN (@Threshold = 0) OR (COALESCE(LongStringLength, 2147483647) < @Threshold) THEN
				NULL
			ELSE
				guid
		END) AS Guid,
		DisplayEditUI
	FROM @Pages
	INNER JOIN tblProperty ON LocalPageID=tblProperty.fkPageID
	INNER JOIN tblPageDefinition ON tblPageDefinition.pkID=tblProperty.fkPageDefinitionID
	LEFT JOIN tblPageDefinitionType AS PDT ON PDT.pkID=tblPageDefinition.fkPageDefinitionTypeID
	WHERE NOT tblPageDefinition.fkPageTypeID IS NULL
	ORDER BY 
		tblProperty.fkPageID,
		tblProperty.fkLanguageBranchID,
		FieldOrder,
		tblProperty.fkPageDefinitionID

	/*Get category information*/
	SELECT 
		fkPageID AS PageID,
		fkCategoryID,
		CategoryType
	FROM tblCategoryPage
	INNER JOIN @Pages ON LocalPageID=tblCategoryPage.fkPageID
	WHERE CategoryType=0
	ORDER BY fkPageID,fkCategoryID

	/* Get access information */
	SELECT
		fkPageID AS PageID,
		tblAccess.Name,
		IsRole,
		AccessMask
	FROM
		@Pages
	INNER JOIN 
	    tblAccess ON LocalPageID=tblAccess.fkPageID
	ORDER BY
		fkPageID
END
GO
